| lmds-package | R Documentation |
A fast dimensionality reduction method scaleable to large numbers of samples. Landmark Multi-Dimensional Scaling (LMDS) is an extension of classical Torgerson MDS, but rather than calculating a complete distance matrix between all pairs of samples, only the distances between a set of landmarks and the samples are calculated.
Maintainer: Robrecht Cannoodt rcannood@gmail.com (ORCID) (rcannood)
Authors:
Wouter Saelens wouter.saelens@gmail.com (ORCID) (zouter)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.